// MessengerApplication.cs
//

using System;
using System.DHTML;
using Microsoft.Live.Messenger;

namespace MessengerApp {

    internal sealed class ContactItem : IDisposable {

        private Contact _contact;
        private DOMElement _contactElement;

        private DOMEventHandler _clickHandler;

        public ContactItem(Contact contact, DOMElement contactElement) {
            _contact = contact;
            _contactElement = contactElement;

            _clickHandler = OnDoubleClick;
            _contactElement.AttachEvent("ondblclick", _clickHandler);
            _contact.CurrentAddress.Presence.PropertyChanged += OnPresencePropertyChanged;

            UpdateDisplay();
        }

        private void OnDoubleClick() {
            MessengerApplication.Current.StartConversation(_contact);
        }

        private void OnPresencePropertyChanged(object sender, Microsoft.Live.Core.PropertyChangedEventArgs e) {
            UpdateDisplay();
        }

        private void UpdateDisplay() {
            IMAddress address = _contact.CurrentAddress;
            IMAddressPresence presence = address.Presence;

            string displayName = presence.DisplayName;
            string addressText = address.Address;
            string message = presence.PersonalMessage;
            string status = "(Online)";

            switch (presence.Status) {
                case PresenceStatus.Offline:
                    status = "(Offline)";
                    break;
                case PresenceStatus.Away:
                    status = "(Away)";
                    break;
            }

            StringBuilder sb = new StringBuilder();
            sb.Append(displayName ?? addressText);
            sb.Append(" ");
            sb.Append(status);
            if (message.Length != 0) {
                sb.Append(" - ");
                sb.Append(message.HTMLEncode());
            }

            _contactElement.InnerHTML = sb.ToString();
        }

        #region Implementation of IDisposable
        public void Dispose() {
            if (_contactElement != null) {
                _contactElement.DetachEvent("ondblclick", _clickHandler);
                _clickHandler = null;
                _contactElement = null;
            }
            _contact = null;
        }
        #endregion
    }
}
