// MessengerApplication.cs
//

using System;
using System.DHTML;
using ScriptFX;
using Microsoft.Live.Messenger;

namespace MessengerApp {

    internal sealed class ConversationItem : IDisposable {

        private Conversation _conversation;
        private DOMElement _conversationElement;

        private DOMElement _transcriptElement;
        private TextAreaElement _messageElement;
        private InputElement _sendButtonElement;

        private DOMEventHandler _clickHandler;

        public ConversationItem(Conversation conversation, DOMElement conversationElement) {
            _conversation = conversation;
            _conversationElement = conversationElement;

            _conversation.MessageReceived += OnMessageReceived;

            CreateUserInterface();
        }

        private void CreateUserInterface() {
            _clickHandler = OnSendButtonClick;

            _transcriptElement = Document.CreateElement("div");
            _transcriptElement.ClassName = "conversationTranscript";

            _messageElement = (TextAreaElement)Document.CreateElement("textarea");
            _messageElement.ClassName += "conversationMessage";

            _sendButtonElement = (InputElement)Document.CreateElement("input");
            _sendButtonElement.ClassName = "conversationSendButton";
            _sendButtonElement.Type = "button";
            _sendButtonElement.Value = "Send";
            _sendButtonElement.AttachEvent("onclick", _clickHandler);

            _conversationElement.AppendChild(_transcriptElement);
            _conversationElement.AppendChild(_messageElement);
            _conversationElement.AppendChild(_sendButtonElement);
        }

        private void AddMessage(TextMessage m) {
            DOMElement messageElement = Document.CreateElement("div");
            messageElement.ClassName = "conversationMessageItem";

            StringBuilder sb = new StringBuilder();
            sb.Append(m.Sender.Presence.DisplayName);
            sb.Append(" says:<br />");
            sb.Append("<span class=\"conversationMessageText\">");
            sb.Append(m.Text);
            sb.Append("</span>");

            messageElement.InnerHTML = sb.ToString();
            _transcriptElement.AppendChild(messageElement);
        }

        private void OnMessageReceived(object sender, MessageReceivedEventArgs e) {
            Message m = e.Message;
            if (m.Type == MessageType.TextMessage) {
                AddMessage((TextMessage)m);
            }
        }

        private void OnSendButtonClick() {
            TextMessage message = new TextMessage(_messageElement.Value, null);
            _messageElement.Value = "";

            _conversation.SendMessage(message, null);
            AddMessage(message);
        }

        #region Implementation of IDisposable
        public void Dispose() {
            if (_sendButtonElement != null) {
                _sendButtonElement.DetachEvent("onclick", _clickHandler);
                _sendButtonElement = null;
                _clickHandler = null;
            }
            _messageElement = null;
            _transcriptElement = null;
            _conversationElement = null;
            _conversation = null;
        }
        #endregion
    }
}
