// MessengerApplication.cs
//

using System;
using System.DHTML;
using ScriptFX;
using Microsoft.Live.Core;
using Microsoft.Live.Messenger;
using Microsoft.Live.Messenger.UI;

namespace MessengerApp {

    internal sealed class MessengerApplication : IDisposable {

        public static MessengerApplication Current;

        private User _user;
        private ArrayList _contacts;
        private ArrayList _conversations;

        static MessengerApplication() {
            Current = new MessengerApplication();
        }

        public MessengerApplication() {
            Application.Current.RegisterDisposableObject(this);

            DOMElement signInElement = Document.GetElementById("signInPanel");

            SignInControl signInControl =
                new SignInControl(signInElement.ID,
                                  (string)signInElement.GetAttribute("privacySource"),
                                  (string)signInElement.GetAttribute("channelSource"),
                                  "en-US");
            signInControl.AuthenticationCompleted += OnAuthenticationCompleted;
        }

        private void OnAuthenticationCompleted(object sender, AuthenticationCompletedEventArgs e) {
            _user = new User(e.Identity);
            _user.SignInCompleted += OnSignInCompleted;
            _user.Conversations.CollectionChanged += OnConversationCollectionChanged;
            _user.SignIn(null);
        }

        private void OnSignInCompleted(object sender, SignInCompletedEventArgs e) {
            if (e.ResultCode == SignInResultCode.Success) {
                DOMElement contactListElement = Document.GetElementById("contactListPanel");

                ShowContacts(contactListElement);

                Document.GetElementById("messengerPanel").Style.Display = "block";
            }
        }

        private void ShowContacts(DOMElement contactListElement) {
            _contacts = new ArrayList();
            foreach (Contact contact in _user.Contacts) {
                DOMElement contactElement = Document.CreateElement("div");
                contactElement.ClassName = "contactItem";
                contactListElement.AppendChild(contactElement);

                ContactItem contactItem = new ContactItem(contact, contactElement);
                _contacts.Add(contactItem);
            }
        }

        private void OnConversationCollectionChanged(object sender, NotifyCollectionChangedEventArgs e) {
            if (e.Action == NotifyCollectionChangedAction.Add) {
                DOMElement conversationListElement = Document.GetElementById("conversationListPanel");

                Conversation conversation = (Conversation)e.NewItems[0];

                DOMElement conversationElement = Document.CreateElement("div");
                conversationElement.ClassName = "conversationItem";
                conversationListElement.AppendChild(conversationElement);

                if (_conversations == null) {
                    _conversations = new ArrayList();
                }

                ConversationItem conversationItem = new ConversationItem(conversation, conversationElement);
                _conversations.Add(conversationItem);
            }
        }

        public void StartConversation(Contact contact) {
            _user.Conversations.Create(contact.CurrentAddress);
        }

        #region Implementation of IDisposable
        public void Dispose() {
            if (_conversations != null) {
                foreach (ConversationItem conversation in _conversations) {
                    conversation.Dispose();
                }
                _conversations = null;
            }
            if (_contacts != null) {
                foreach (ContactItem contact in _contacts) {
                    contact.Dispose();
                }
                _contacts = null;
            }
            if (_user != null) {
                _user.Dispose();
                _user = null;
            }
        }
        #endregion
    }
}
