//-----------------------------------------------------------------------
// <copyright file="InviteAddressCompletedEventArgs.cs" company="Microsoft">
//     Copyright (c) Microsoft Corporation.  All rights reserved.
// </copyright>
//-----------------------------------------------------------------------

namespace Microsoft.Live.Messenger
{
    using System;

    /// <summary>
    /// Represents the method that will handle the <see cref="Conversation.InviteAddressCompleted"/> event of <see cref="Conversation"/>.
    /// </summary>
    /// <param name="sender">The source of the event.</param>
    /// <param name="e">An <see cref="InviteAddressCompletedEventArgs"/> object that contains event data.</param>
    public delegate void InviteAddressCompletedEventHandler(object sender, InviteAddressCompletedEventArgs e);

    /// <summary>
    /// Provides data for the <see cref="Conversation.InviteAddressCompleted"/> event.
    /// </summary>
    public class InviteAddressCompletedEventArgs : EventArgs
    {
        private readonly InviteAddressResultCode resultCode;
        private readonly IMAddress address;
        private readonly object userState;

        /// <summary>
        /// Initializes a new instance of the <see cref="InviteAddressCompletedEventArgs"/> class.
        /// </summary>
        /// <param name="resultCode">The result code.</param>
        /// <param name="address">The address that was invited.</param>
        /// <param name="userState">The User state.</param>
        public InviteAddressCompletedEventArgs(
            InviteAddressResultCode resultCode,
            IMAddress address,
            object userState)
        {
            this.resultCode = resultCode;
            this.address = address;
            this.userState = userState;
        }

        /// <summary>
        /// Gets the result code.
        /// </summary>
        public InviteAddressResultCode ResultCode
        {
            get { return this.resultCode; }
        }

        /// <summary>
        /// Gets the IM address
        /// </summary>
        public IMAddress IMAddress
        {
            get { return this.address; }
        }

        /// <summary>
        /// Gets the unique identifier for the asynchronous task.
        /// </summary>
        public object UserState
        {
            get { return this.userState; }
        }
    }
}