//-----------------------------------------------------------------------
// <copyright file="SendMessageFailedEventArgs.cs" company="Microsoft">
//     Copyright (c) Microsoft Corporation.  All rights reserved.
// </copyright>
//-----------------------------------------------------------------------

namespace Microsoft.Live.Messenger
{
    using System;

    /// <summary>
    /// Represents the method that will handle the <see cref="Conversation.SendMessageFailed"/> event of <see cref="Conversation"/>.
    /// </summary>
    /// <param name="sender">The source of the event.</param>
    /// <param name="e">A <see cref="SendMessageFailedEventArgs"/> object that contains event data.</param>
    public delegate void SendMessageFailedEventHandler(object sender, SendMessageFailedEventArgs e);

    /// <summary>
    /// Provides data for the <see cref="Conversation.SendMessageFailed"/> event.
    /// </summary>
    public class SendMessageFailedEventArgs : EventArgs
    {
        private readonly SendMessageResultCode resultCode;
        private readonly Message message;
        private readonly object userState;

        /// <summary>
        /// Initializes a new instance of the <see cref="SendMessageFailedEventArgs"/> class.
        /// </summary>
        /// <param name="resultCode">The result code.</param>
        /// <param name="message">The message that could not be delivered.</param>
        /// <param name="userState">The User state</param>
        public SendMessageFailedEventArgs(
            SendMessageResultCode resultCode,
            Message message,
            object userState)
        {
            this.resultCode = resultCode;
            this.message = message;
            this.userState = userState;
        }

        /// <summary>
        /// Gets the result code.
        /// </summary>
        public SendMessageResultCode ResultCode
        {
            get { return this.resultCode; }
        }

        /// <summary>
        /// Gets the message that could not be delivered.
        /// </summary>
        public Message Message
        {
            get { return this.message; }
        }

        /// <summary>
        /// Gets the User state
        /// </summary>
        public object UserState
        {
            get { return this.userState; }
        }
    }
}