//-----------------------------------------------------------------------
// <copyright file="PresenceProperty.cs" company="Microsoft">
//     Copyright (c) Microsoft Corporation.  All rights reserved.
// </copyright>
//-----------------------------------------------------------------------

namespace Microsoft.Live.Messenger
{
    using System;

    /// <summary>
    /// Represents a presence property.
    /// </summary>
    public class PresenceProperty
    {
        private readonly string name;
        private readonly string value;

        /// <summary>
        /// Initializes a new instance of the <see cref="PresenceProperty"/> class.
        /// </summary>
        /// <param name="name">The name.</param>
        /// <param name="value">The value.</param>
        public PresenceProperty(
            string name,
            string value)
        {
            if (String.IsNullOrEmpty(name))
            {
                throw ExceptionHelper.CreateArgumentNullException("name");
            }

            if (value == null)
            {
                throw ExceptionHelper.CreateArgumentNullException("value");
            }

            this.name = name;
            this.value = value;
        }

        /// <summary>
        /// Gets the name.
        /// </summary>
        public string Name
        {
            get { return this.name; }
        }

        /// <summary>
        /// Gets the value.
        /// </summary>
        public string Value
        {
            get { return this.value; }
        }
    }
}